@@ -1,12 +1,12 @@
 package Perl6::Pod::Parser::AddHeadLevels;
 
-#$Id: AddHeadLevels.pm 572 2009-07-07 17:46:25Z zag $
+#$Id$
 
 =pod
 
 =head1 NAME
 
-Perl6::Pod::Parser - base class for perl6's pod parsers
+Perl6::Pod::Parser::AddHeadLevels - group headers by level
 
 =head1 SYNOPSIS
 
@@ -44,14 +44,15 @@ sub on_start_document {
 sub current_level {
     my $self = shift;
     my $current = $self->_lstack->[-1] || return 0;
-    return $current->attrs_by_name->{LEVEL};
+    return $current->attrs_by_name->{hlevel};
 }
 
 sub switch_to_level {
-    my ( $self, $to_level ) = @_;
+    my ( $self, $to_level, $lname ) = @_;
     my $current_level = $self->current_level;
-    my $hl = $self->mk_block( 'headlevel', qq!:level($to_level)! );
-    $hl->attrs_by_name->{LEVEL} = $to_level;
+    my $hl =
+      $self->mk_block( 'headlevel', qq!:level($to_level) :child<$lname>)! );
+    $hl->attrs_by_name->{hlevel} = $to_level;
     if ( $current_level < $to_level ) {
 
         #up level
@@ -93,9 +94,17 @@ sub switch_to_level {
 sub on_start_element {
     my ( $self, $el ) = @_;
     my $lname = $el->local_name;
-    return $el unless ( $lname =~ /^head(\d+)/ );
-    my $to_level = $1;
-    my @comms    = $self->switch_to_level($to_level);
+
+    #ALL SEMANTIC BLOCKS HAVE level 1
+    # all sem blocks is UPPER CASE ( AND FORMATTING CODES!!!!)
+    my $is_block = !$el->isa('Perl6::Pod::FormattingCode');
+
+    #skip special BLOCKS _SPECIAL_
+    my $is_semantic =
+      $is_block && ( $lname eq uc($lname) ) && ( $lname !~ /^_/ );
+    return $el unless ( $is_semantic or $lname =~ /^head(\d+)/ );
+    my $to_level = $is_semantic ? 1 : $1;
+    my @comms = $self->switch_to_level( $to_level, $lname );
     return [ @comms, $el ];
 }
 
