@@ -12,8 +12,10 @@ sub on_start_element {
     }
     return $el;
 }
+
 1;
 
+
 package Perl6::Pod::To::DocBook;
 
 #$Id$
@@ -256,6 +258,15 @@ sub export_block_NAME {
       ->add_content( $self->_make_events(@in) ) ;
 }
 
+#for N clean any extra tags
+sub export_block__NOTES_ {
+    return;
+}
+
+sub export_block__NOTE_ {
+    return ;
+}
+
 1;
 __END__
 
